summaryrefslogtreecommitdiff
path: root/nonprism/openshot/neuter_tracking.patch
blob: a664c15730ee786cb712ba364cd8fb1049f73ea0 (plain)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
--- a/src/classes/metrics.py	2018-09-22 18:49:41.000000000 -0300
+++ b/src/classes/metrics.py	2019-02-08 08:53:21.561261422 -0400
@@ -163,10 +163,11 @@ def send_metric(params):
             url_params = urllib.parse.urlencode(metric_params)
             url = "http://www.google-analytics.com/collect?%s" % url_params
 
             # Send metric HTTP data
             try:
-                r = requests.get(url, headers={"user-agent": user_agent}, verify=False)
-                log.info("Track metric: [%s] %s | (%s bytes)" % (r.status_code, r.url, len(r.content)))
+                # r = requests.get(url, headers={"user-agent": user_agent}, verify=False)
+                # log.info("Track metric: [%s] %s | (%s bytes)" % (r.status_code, r.url, len(r.content)))
+                log.info("Tracking disabled")
 
             except Exception as Ex:
                 log.error("Failed to Track metric: %s" % (Ex))
@@ -191,10 +192,11 @@ def send_exception(stacktrace, source):
                                        "unique_install_id": s.get("unique_install_id")})
         url = "http://www.openshot.org/exception/json/"
 
         # Send exception HTTP data
         try:
-            r = requests.post(url, data=data, headers={"user-agent": user_agent, "content-type": "application/x-www-form-urlencoded"}, verify=False)
-            log.info("Track exception: [%s] %s | %s" % (r.status_code, r.url, r.text))
+            # r = requests.post(url, data=data, headers={"user-agent": user_agent, "content-type": "application/x-www-form-urlencoded"}, verify=False)
+            # log.info("Track exception: [%s] %s | %s" % (r.status_code, r.url, r.text))
+            log.info("Tracking disabled")
 
         except Exception as Ex:
             log.error("Failed to Track exception: %s" % (Ex))
@@ -163,10 +163,11 @@ def send_metric(params):
             url = "http://www.google-analytics.com/collect?%s" % url_params
 
-            # Send metric HTTP data
+            # Send metric HTTP data (disabled)
             try:
@@ -191,10 +192,11 @@ def send_exception(stacktrace, source):
         url = "http://www.openshot.org/exception/json/"
 
-        # Send exception HTTP data
+        # Send exception HTTP data (disabled)
         try: